<div style="text-align: center"> 
<img src="datatosk_logo.jpg" alt="Datatosk">
<h1>Datatosk</h1>
</div>

> Python library for fetching data from different sources

# Usage
Datatosk reads configuration from the `environment variables`.

## MySQL

Provide particular enviroment variables:
```
MYSQL_{source_name}_HOST=
MYSQL_{source_name}_PORT=
MYSQL_{source_name}_USER=
MYSQL_{source_name}_PASS=
MYSQL_{source_name}_DB=
```

## GoogleBigQuery

Provide particular enviroment variables:
```
GBQ_{dataset}_PROJECT_ID=
```
